@@ -1,6 +1,6 @@
 package Hubot::Robot;
 {
-  $Hubot::Robot::VERSION = '0.0.3';
+  $Hubot::Robot::VERSION = '0.0.4';
 }
 
 use Moose;
@@ -72,7 +72,8 @@ sub userForId {
     }
 
     my $options_room = $options->{room} || '';
-    if ($options_room ne $user->{room}) {
+    if ($options_room && (!$user->{room} || $user->{room} ne $options_room)) {
+        $user = Hubot::User->new({ id => $id, %$options });
         $self->brain->{data}{users}{$id} = $user;
     }
 
